==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Aucune des entités sélectionnées.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Aucune des entités sélectionnées.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 sur calque &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 sur %3 calques</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 entités sur calque &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 entités sur %2 calques</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crée un nouveau bloc à partir des entités existantes
Désélectionne toutes les entités
Désélectionne&amp;r entités coupées</translatorcomment>
        <translation type="vanished">entités</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Curseur dans la Ligne de Commande
Curseur dans la ligne de &amp;commande
Indiquer le premier point de cassure sur une polyligne</translatorcomment>
        <translation type="obsolete">sur</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">sur</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">calque &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 calques</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entités sélectionnées :
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Aucune des entités sélectionnées.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Aucune des entités sélectionnées.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 sur calque &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 sur %3 calques</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation>
            <numerusform>%n entité sur calque &apos;%1&apos;</numerusform>
            <numerusform>%n entités sur calque &apos;%1&apos;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation>
            <numerusform>%n entité</numerusform>
            <numerusform>%n entités</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation>
            <numerusform>%n calque</numerusform>
            <numerusform>%n calques</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 entités sur calque &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 entités sur %2 calques</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crée un nouveau bloc à partir des entités existantes
Désélectionne toutes les entités
Désélectionne&amp;r entités coupées</translatorcomment>
        <translation type="vanished">entités</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Curseur dans la Ligne de Commande
Curseur dans la ligne de &amp;commande
Indiquer le premier point de cassure sur une polyligne</translatorcomment>
        <translation type="obsolete">sur</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>sur</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">calque &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 calques</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entités sélectionnées :
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>
